==> nmail-php-patch-2.3.1-to-2.4.0.tgz: tools/mail_box_dbrebuild.php <==
#!/usr/bin/php
<?
chdir(dirname(__FILE__));
require_once('../nmail/include/global.php');
require_once("include/mail_lib.php");
require_once("include/file.php");


// 󿡼 .
if ($_SERVER['DOCUMENT_ROOT'] || $_SERVER['SERVER_SOFTWARE'])
{
	die("Access Denied");	
}	// if()


echo "[Nmail]   ϵŸ ϴ ۾\n\n";
echo "1.  Ϻ     ʴ  ذ ġ  쿡 ˴ϴ.\n";
echo "2.   ִ   ٽ ؼ  Ʈϱ  Ͼ    ð ҿ˴ϴ.\n";
echo "3. ġ 1ȸ Ű ˴ϴ.\n";

// set
set_time_limit(0);
ini_set('memory_limit', '512M');
$memory_limit = ini_get('memory_limit');
#echo "memory_get_usage: ".number_format(memory_get_usage()) . "\n"; 

$_start = getmicrotime();

// Է° Ȯ.
$d_name_input = addslashes($_SERVER['argv'][1]);
$m_id_input = addslashes($_SERVER['argv'][2]);
#if (!$d_name_input || !$m_id_input)
if (!$d_name_input)
{
	die("  )\n    - Ư ȸ   : ".$_SERVER['PHP_SELF']." domain.com userid\n    - Ư  : ".$_SERVER['PHP_SELF']." domain.com\n    - ü  : ".$_SERVER['PHP_SELF']." ALL\n");
}	// if()


if ($d_name_input == 'ALL')
{
	$dm = db_get_rows("SELECT d_no, d_name FROM " . $TB['DOMAIN'] . "");
} else 
{
	$d_no = db_get_one("SELECT d_no FROM " . $TB['DOMAIN'] . " WHERE d_name = '" . $d_name_input . "'");
	if (!$d_no)
		die(" ʴ Դϴ.\n=> " . $d_name_input."\n");

	$q_where = '';
	if ($m_id_input)
	{
		$q_where = " m_id = '" . $m_id_input . "' AND ";
	}	// if()

	$dm = array(array('d_no'=>$d_no, 'd_name'=>$d_name_input));
}	// if()

for ($di=0; $di<sizeof($dm); $di++)
{
	$d_no = $dm[$di]['d_no'];
	$d_name = $dm[$di]['d_name'];

	echo "\n";
	echo "#############################################\n";
	echo "# [".($di+1)."/".sizeof($dm)."] ".$d_name."\n";
	echo "#############################################\n";

	// [2007-07-21] ϸ Ʈ  
	//$mbr = db_get_rows("SELECT m_no, m_id, m_mail_file_group FROM " . $TB['MEMBER'] . " WHERE ".$q_where." d_no = '" . $d_no . "'");
	$mbr = db_get_rows("SELECT m_no, m_id, m_mail_file_group FROM " . $TB['MEMBER'] . " WHERE ".$q_where." d_no = '" . $d_no . "' AND m_usertype IS NULL");
	$mbr_cnt = sizeof($mbr);
	if ($mbr_cnt < 1)
	{
		if ($m_id_input)
		{
			die(" ʴ Դϴ.\n=> " . $m_id_input."\n");
		} else if ($d_name_input != 'ALL')
		{
			die("γ ϵ ڰ ϴ.\n");
		}	// if()
	} else 
	{
		echo " ".number_format($mbr_cnt)." ϵŸ  ۾ մϴ.\n";


		for ($mi=0; $mi<$mbr_cnt; $mi++)
		{
			// set
			$m_id = $mbr[$mi]['m_id'];
			$AUTH['auth_m_no'] = $mbr[$mi]['m_no'];
			$AUTH['auth_m_id'] = $mbr[$mi]['m_id'];
			$AUTH['auth_m_mail_file_group'] = $mbr[$mi]['m_mail_file_group'];
			$AUTH['auth_m_mf_table'] = $G_SYS[PRE_FIX] . 'mail_file_' . $d_no . '_' . $mbr[$mi]['m_mail_file_group'];
			$G_SYS['MAIL_DOMAIN'] = $d_name;

			#echo "[".($mi+1)."/".$mbr_cnt."][".$m_id."]  մϴ.(" . round((getmicrotime() - $_start),4) . "sec)\n";

		// Ϲڽ
			$DEBUG['get_mail_box']['start'] = getmicrotime();
			$sql = "
				SELECT
					mb_id
				FROM
					".$TB['MAIL_BOX']."
				WHERE
					m_no='". $AUTH['auth_m_no'] . "'
				ORDER BY
					mb_sort
				";
			$mb = db_get_rows($sql);
			$DEBUG['get_mail_box']['exec'] += getmicrotime() - $DEBUG['get_mail_box']['start'];

			$DEBUG['get_maildb_cnt']['start'] = getmicrotime();
			$maildb_cnt = array();
			$mb_dir_id = array();
			for ($m=0; $m<sizeof($mb); $m++)
			{
				$DEBUG['get_mf_filenames']['start'] = getmicrotime();
				$sql = "
					SELECT
						mf_filename, mf_no
					FROM
						" .$AUTH['auth_m_mf_table'] . "
					WHERE
						m_no='" . $AUTH['auth_m_no'] . "'
						AND mb_id = '" . $mb[$m]['mb_id'] . "'
					";
				$rows = db_get_rows($sql);
				$rows_cnt = sizeof($rows);
				$DEBUG['get_mf_filenames']['exec'] += getmicrotime() - $DEBUG['get_mf_filenames']['start'];
				echo "[".($mi+1)."/".$mbr_cnt."][".$m_id."] ".$mb[$m]['mb_id']." : ".$rows_cnt . "\n";

				for ($r=0; $r<$rows_cnt; $r++)
				{
					$mf_dir = get_mail_dir().'/'.get_mb_dir($mb[$m]['mb_id']).'/';
					#echo $AUTH['auth_m_mf_table'].' / '.$mf_dir.$rows[$r]['mf_filename'].' / '.$rows[$r]['mf_no'].' / '.$AUTH['auth_m_no']."\n";
					mail_db_rebuild($AUTH['auth_m_mf_table'], $mf_dir.$rows[$r]['mf_filename'], $rows[$r]['mf_no'], $AUTH['auth_m_no']);
				}	// for()

				flush();
			}	// for()
			$DEBUG['get_maildb_cnt']['exec'] += getmicrotime() - $DEBUG['get_maildb_cnt']['start'];

		}	// for()

		echo "[" . round((getmicrotime() - $_start),4) . "sec]ϵŸ  ۾ ϷǾϴ.\n";

	}	// if()

}	// for()

if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN')
{
	#system('pause');
}	// if()

#require_once('include/global_end.php');
?>

==> nmail-php-patch-2.6.1-to-2.6.12.tgz: tools/mail_box_dbrebuild.php <==
#!/usr/bin/php
<?
chdir(dirname(__FILE__));
require_once('../nmail/include/global.php');
require_once("include/mail_lib.php");
require_once("include/file.php");


// 󿡼 .
if ($_SERVER['DOCUMENT_ROOT'] || $_SERVER['SERVER_SOFTWARE'])
{
	die("Access Denied");	
}	// if()


echo "[Nmail]   ϵŸ ϴ ۾\n\n";
echo "1.  Ϻ     ʴ  ذ ġ  쿡 ˴ϴ.\n";
echo "2.   ִ   ٽ ؼ  Ʈϱ  Ͼ    ð ҿ˴ϴ.\n";
echo "3. ġ 1ȸ Ű ˴ϴ.\n";

// set
set_time_limit(0);
ini_set('memory_limit', '2047M');
$memory_limit = ini_get('memory_limit');
#echo "memory_get_usage: ".number_format(memory_get_usage()) . "\n"; 

$_start = getmicrotime();

// Է° Ȯ.
$d_name_input = addslashes(trim($_SERVER['argv'][1]));
$m_id_input = addslashes(trim($_SERVER['argv'][2]));
#if (!$d_name_input || !$m_id_input)
if (!$d_name_input)
{
	die("  )\n    - Ư ȸ   : ".$_SERVER['PHP_SELF']." domain.com userid\n    - Ư  : ".$_SERVER['PHP_SELF']." domain.com\n    - ü  : ".$_SERVER['PHP_SELF']." ALL\n    - ü , ֱ 30ϰ ϸ : ".$_SERVER['PHP_SELF']." ALL ".escapeshellarg(' ')." 30\n");
}	// if()

$q_where = '';
if ($d_name_input == 'ALL')
{
	$dm = db_get_rows("SELECT d_no, d_name FROM " . $TB['DOMAIN'] . "");
} else 
{
	$d_no = db_get_one("SELECT d_no FROM " . $TB['DOMAIN'] . " WHERE d_name = '" . $d_name_input . "'");
	if (!$d_no)
		die(" ʴ Դϴ.\n=> " . $d_name_input."\n");

	if ($m_id_input)
	{
		$q_where = " m_id = '" . $m_id_input . "' AND ";
	}	// if()

	$dm = array(array('d_no'=>$d_no, 'd_name'=>$d_name_input));
}	// if()

// [2013-10-22] ֱ 30ϰ ϸ   ֵ  ߰.
$mf_q_where = '';
if (is_numeric($_SERVER['argv'][3]))
{
	$mf_arrival_date_start = date('Y-m-d', (time() - (86400*(int)$_SERVER['argv'][3])));
	$mf_q_where = " AND mf_arrival_date >= '".$mf_arrival_date_start." 00:00:00'";	
	echo "\n  Ⱓ  : ".$mf_arrival_date_start." ¥ ķ ۼŵ ϵŸ մϴ.\n";
}	// if()

for ($di=0; $di<sizeof($dm); $di++)
{
	$d_no = $dm[$di]['d_no'];
	$d_name = $dm[$di]['d_name'];

	echo "\n";
	echo "#############################################\n";
	echo "# [".($di+1)."/".sizeof($dm)."] ".$d_name."\n";
	echo "#############################################\n";

	// [2007-07-21] ϸ Ʈ  
	//$mbr = db_get_rows("SELECT m_no, m_id, m_mail_file_group FROM " . $TB['MEMBER'] . " WHERE ".$q_where." d_no = '" . $d_no . "'");
	$mbr = db_get_rows("SELECT m_no, m_id, m_mail_file_group FROM " . $TB['MEMBER'] . " WHERE ".$q_where." d_no = '" . $d_no . "' AND m_usertype IS NULL");
	$mbr_cnt = sizeof($mbr);
	if ($mbr_cnt < 1)
	{
		if ($m_id_input)
		{
			die(" ʴ Դϴ.\n=> " . $m_id_input."\n");
		} else if ($d_name_input != 'ALL')
		{
			die("γ ϵ ڰ ϴ.\n");
		}	// if()
	} else 
	{
		echo " ".number_format($mbr_cnt)." ϵŸ  ۾ մϴ.\n";


		for ($mi=0; $mi<$mbr_cnt; $mi++)
		{
			// set
			$m_id = $mbr[$mi]['m_id'];
			$AUTH['auth_m_no'] = $mbr[$mi]['m_no'];
			$AUTH['auth_m_id'] = $mbr[$mi]['m_id'];
			$AUTH['auth_m_mail_file_group'] = $mbr[$mi]['m_mail_file_group'];
			$AUTH['auth_m_mf_table'] = $G_SYS[PRE_FIX] . 'mail_file_' . $d_no . '_' . $mbr[$mi]['m_mail_file_group'];
			$G_SYS['MAIL_DOMAIN'] = $d_name;

			#echo "[".($mi+1)."/".$mbr_cnt."][".$m_id."]  մϴ.(" . round((getmicrotime() - $_start),4) . "sec)\n";

		// Ϲڽ
			$DEBUG['get_mail_box']['start'] = getmicrotime();
			$sql = "
				SELECT
					mb_id
				FROM
					".$TB['MAIL_BOX']."
				WHERE
					m_no='". $AUTH['auth_m_no'] . "'
				ORDER BY
					mb_sort
				";
			$mb = db_get_rows($sql);
			$DEBUG['get_mail_box']['exec'] += getmicrotime() - $DEBUG['get_mail_box']['start'];

			$DEBUG['get_maildb_cnt']['start'] = getmicrotime();
			$maildb_cnt = array();
			$mb_dir_id = array();
			for ($m=0; $m<sizeof($mb); $m++)
			{
				$DEBUG['get_mf_filenames']['start'] = getmicrotime();
				$sql = "
					SELECT
						mf_filename, mf_no
					FROM
						" .$AUTH['auth_m_mf_table'] . "
					WHERE
						m_no='" . $AUTH['auth_m_no'] . "'
						AND mb_id = '" . $mb[$m]['mb_id'] . "'
						".$mf_q_where;
				$rows = db_get_rows($sql);
				$rows_cnt = sizeof($rows);
				$DEBUG['get_mf_filenames']['exec'] += getmicrotime() - $DEBUG['get_mf_filenames']['start'];
				if ($rows_cnt > 0)
					echo "[".($mi+1)."/".$mbr_cnt."][".$m_id."] ".$mb[$m]['mb_id']." : ".$rows_cnt . "\n";

				for ($r=0; $r<$rows_cnt; $r++)
				{
					$mf_dir = get_mail_dir().'/'.get_mb_dir($mb[$m]['mb_id']).'/';
					#echo $AUTH['auth_m_mf_table'].' / '.$mf_dir.$rows[$r]['mf_filename'].' / '.$rows[$r]['mf_no'].' / '.$AUTH['auth_m_no']."\n";
					mail_db_rebuild($AUTH['auth_m_mf_table'], $mf_dir.$rows[$r]['mf_filename'], $rows[$r]['mf_no'], $AUTH['auth_m_no']);

					// [2013-10-24] 1000Ǹ 0.2ʾ .
					if ($r%1000 == 0 && $r > 0)
						usleep(200000);		// 0.2s
				}	// for()
			}	// for()
			$DEBUG['get_maildb_cnt']['exec'] += getmicrotime() - $DEBUG['get_maildb_cnt']['start'];

		}	// for()

		echo "[" . round((getmicrotime() - $_start),4) . "sec]ϵŸ  ۾ ϷǾϴ.\n";

	}	// if()

}	// for()

if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN')
{
	#system('pause');
}	// if()

#require_once('include/global_end.php');
?>
